# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add image ingestion templates

Revision ID: f0f6d7be45e3
Revises: dcbfdfafe16c
Create Date: 2021-07-28 14:24:40.213660

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "f0f6d7be45e3"
down_revision = "dcbfdfafe16c"
branch_labels = None
depends_on = None


content = """{
  "project_code": "{{projectCode}}",
  "band_code": "{{bands}}",
  "configurations": "{{configurations}}",
  "starttime": null,
  "endtime": null,
  "exposure_time": null,
  "rms_noise": null,
  "image_tags": "",
  "product_tags": "",
  "collection_name": "",
  "calibration_level": 2
}
"""

metadata_content = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_cms_imaging",
  "systemId": "{{request_id}}",
  "creationTime": "{{created_at}}",
  "productLocator": "{{product_locator}}",
  "calProductLocator": "{{cal_locator}}",
  "projectMetadata": {
      "projectCode": "{{projectCode}}",
      "title": "{{title}}",
      "telescope": "{{telescope}}",
      "startTime": "{{startTime}}",
      "observer": "{{observer}}"
    },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}",
  "calibrationSourceDirectory":"{{cms_path}}",
  "cmsName":"{{sdmId}}.ms"
}

"""

condor_content = """executable = ingest_image.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/conveyor, $(SBIN_PATH)/ingest_envoy, $(SBIN_PATH)/ingest, $(SBIN_PATH)/image-product-collector.sh, ./metadata.json, ./aux_image_metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue


"""


old_metadata = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_cms_imaging",
  "systemId": "{{request_id}}",
  "creationTime": "{{created_at}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
      "projectCode": "{{projectCode}}",
      "title": "{{title}}",
      "telescope": "{{telescope}}",
      "startTime": "{{startTime}}",
      "observer": "{{observer}}"
    },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}",
  "calibrationSourceDirectory":"{{cms_path}}",
  "cmsName":"{{sdmId}}.ms"
}

"""

old_condor = """executable = ingest_image.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/conveyor, $(SBIN_PATH)/ingest_envoy, $(SBIN_PATH)/ingest, $(SBIN_PATH)/image-product-collector.sh, ./metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue


"""


def upgrade():
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('aux_image_metadata.json', E'{content}', 'ingest_image')
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{metadata_content}' WHERE filename='metadata.json' AND workflow_name = 'std_cms_imaging'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{condor_content}' WHERE filename='ingest_image.condor'
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='aux_image_metadata.json' AND workflow_name='ingest_image'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_metadata}' WHERE filename='metadata.json' AND workflow_name = 'std_cms_imaging'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_condor}' WHERE filename='ingest_image.condor'
        """
    )
